@@ -1,15 +1,19 @@
 <?php
 
+use JetBrains\PhpStorm\Internal\LanguageLevelTypeAware;
+use JetBrains\PhpStorm\Internal\PhpStormStubsElementAvailable;
+use JetBrains\PhpStorm\Pure;
+
 /**
  * Add two arbitrary precision numbers
  * @link https://php.net/manual/en/function.bcadd.php
- * @param string $left_operand <p>
+ * @param string $num1 <p>
  * The left operand, as a string.
  * </p>
- * @param string $right_operand <p>
+ * @param string $num2 <p>
  * The right operand, as a string.
  * </p>
- * @param int $scale [optional] <p>
+ * @param int|null $scale [optional] <p>
  * This optional parameter is used to set the number of digits after the
  * decimal place in the result. If omitted, it will default to the scale
  * set globally with the {@link bcscale()} function, or fallback to 0 if
@@ -17,18 +21,20 @@
  * </p>
  * @return string The sum of the two operands, as a string.
  */
-function bcadd ($left_operand, $right_operand, $scale = 0) {}
+#[Pure]
+function bcadd (string $num1, string $num2, ?int $scale = 0): string
+{}
 
 /**
  * Subtract one arbitrary precision number from another
  * @link https://php.net/manual/en/function.bcsub.php
- * @param string $left_operand <p>
+ * @param string $num1 <p>
  * The left operand, as a string.
  * </p>
- * @param string $right_operand <p>
+ * @param string $num2 <p>
  * The right operand, as a string.
  * </p>
- * @param int $scale [optional] <p>
+ * @param int|null $scale [optional] <p>
  * This optional parameter is used to set the number of digits after the
  * decimal place in the result. If omitted, it will default to the scale
  * set globally with the {@link bcscale()} function, or fallback to 0 if
@@ -36,18 +42,20 @@ function bcadd ($left_operand, $right_operand, $scale = 0) {}
  * </p>
  * @return string The result of the subtraction, as a string.
  */
-function bcsub ($left_operand, $right_operand, $scale = 0) {}
+#[Pure]
+function bcsub (string $num1, string $num2, ?int $scale = 0): string
+{}
 
 /**
  * Multiply two arbitrary precision numbers
  * @link https://php.net/manual/en/function.bcmul.php
- * @param string $left_operand <p>
+ * @param string $num1 <p>
  * The left operand, as a string.
  * </p>
- * @param string $right_operand <p>
+ * @param string $num2 <p>
  * The right operand, as a string.
  * </p>
- * @param int $scale [optional] <p>
+ * @param int|null $scale [optional] <p>
  * This optional parameter is used to set the number of digits after the
  * decimal place in the result. If omitted, it will default to the scale
  * set globally with the {@link bcscale()} function, or fallback to 0 if
@@ -55,18 +63,20 @@ function bcsub ($left_operand, $right_operand, $scale = 0) {}
  * </p>
  * @return string the result as a string.
  */
-function bcmul ($left_operand, $right_operand, $scale = 0) {}
+#[Pure]
+function bcmul (string $num1, string $num2, ?int $scale = 0): string
+{}
 
 /**
  * Divide two arbitrary precision numbers
  * @link https://php.net/manual/en/function.bcdiv.php
- * @param string $dividend <p>
+ * @param string $num1 <p>
  * The dividend, as a string.
  * </p>
- * @param string $divisor <p>
+ * @param string $num2 <p>
  * The divisor, as a string.
  * </p>
- * @param int $scale [optional] <p>
+ * @param int|null $scale [optional] <p>
  * This optional parameter is used to set the number of digits after the
  * decimal place in the result. If omitted, it will default to the scale
  * set globally with the {@link bcscale()} function, or fallback to 0 if
@@ -75,18 +85,44 @@ function bcmul ($left_operand, $right_operand, $scale = 0) {}
  * @return string|null the result of the division as a string, or <b>NULL</b> if
  * <i>divisor</i> is 0.
  */
-function bcdiv ($dividend, $divisor, $scale = 0) {}
+#[Pure]
+#[PhpStormStubsElementAvailable(to: '7.4')]
+function bcdiv (string $num1, string $num2, ?int $scale = 0): ?string
+{}
+
+/**
+ * Divide two arbitrary precision numbers
+ * @link https://php.net/manual/en/function.bcdiv.php
+ * @param string $num1 <p>
+ * The dividend, as a string.
+ * </p>
+ * @param string $num2 <p>
+ * The divisor, as a string.
+ * </p>
+ * @param int|null $scale [optional] <p>
+ * This optional parameter is used to set the number of digits after the
+ * decimal place in the result. If omitted, it will default to the scale
+ * set globally with the {@link bcscale()} function, or fallback to 0 if
+ * this has not been set.
+ * </p>
+ * @return string the result of the division as a string.
+ * @throws \DivisionByZeroError if <i>divisor</i> is 0. Available since PHP 8.0.
+ */
+#[Pure]
+#[PhpStormStubsElementAvailable('8.0')]
+function bcdiv (string $num1, string $num2, ?int $scale = 0): string
+{}
 
 /**
  * Get modulus of an arbitrary precision number
  * @link https://php.net/manual/en/function.bcmod.php
- * @param string $dividend <p>
+ * @param string $num1 <p>
  * The dividend, as a string. Since PHP 7.2, the divided is no longer truncated to an integer.
  * </p>
- * @param string $divisor <p>
+ * @param string $num2 <p>
  * The divisor, as a string. Since PHP 7.2, the divisor is no longer truncated to an integer.
  * </p>
- * @param int $scale [optional] <p>
+ * @param int|null $scale [optional] <p>
  * This optional parameter is used to set the number of digits after the
  * decimal place in the result. If omitted, it will default to the scale
  * set globally with the {@link bcscale()} function, or fallback to 0 if
@@ -95,12 +131,38 @@ function bcdiv ($dividend, $divisor, $scale = 0) {}
  * @return string|null the modulus as a string, or <b>NULL</b> if
  * <i>divisor</i> is 0.
  */
-function bcmod ($dividend, $divisor, $scale = 0) {}
+#[Pure]
+#[PhpStormStubsElementAvailable(to: '7.4')]
+function bcmod (string $num1, string $num2, ?int $scale = 0): ?string
+{}
+
+/**
+ * Get modulus of an arbitrary precision number
+ * @link https://php.net/manual/en/function.bcmod.php
+ * @param string $num1 <p>
+ * The dividend, as a string. Since PHP 7.2, the divided is no longer truncated to an integer.
+ * </p>
+ * @param string $num2 <p>
+ * The divisor, as a string. Since PHP 7.2, the divisor is no longer truncated to an integer.
+ * </p>
+ * @param int|null $scale [optional] <p>
+ * This optional parameter is used to set the number of digits after the
+ * decimal place in the result. If omitted, it will default to the scale
+ * set globally with the {@link bcscale()} function, or fallback to 0 if
+ * this has not been set. Available since PHP 7.2.
+ * </p>
+ * @return string the modulus as a string.
+ * @throws \DivisionByZeroError if <i>divisor</i> is 0. Available since PHP 8.0.
+ */
+#[Pure]
+#[PhpStormStubsElementAvailable('8.0')]
+function bcmod (string $num1, string $num2, ?int $scale = 0): string
+{}
 
 /**
  * Raise an arbitrary precision number to another
  * @link https://php.net/manual/en/function.bcpow.php
- * @param string $base <p>
+ * @param string $num <p>
  * The base, as a string.
  * </p>
  * @param string $exponent <p>
@@ -108,7 +170,7 @@ function bcmod ($dividend, $divisor, $scale = 0) {}
  * The valid range of the exponent is platform specific, but is at least
  * -2147483648 to 2147483647.
  * </p>
- * @param int $scale [optional] <p>
+ * @param int|null $scale [optional] <p>
  * This optional parameter is used to set the number of digits after the
  * decimal place in the result. If omitted, it will default to the scale
  * set globally with the {@link bcscale()} function, or fallback to 0 if
@@ -116,40 +178,56 @@ function bcmod ($dividend, $divisor, $scale = 0) {}
  * </p>
  * @return string the result as a string.
  */
-function bcpow ($base, $exponent, $scale = 0) {}
+#[Pure]
+function bcpow (string $num, string $exponent, ?int $scale = 0): string
+{}
 
 /**
  * Get the square root of an arbitrary precision number
  * @link https://php.net/manual/en/function.bcsqrt.php
- * @param string $operand <p>
+ * @param string $num <p>
  * The operand, as a string.
  * </p>
- * @param int $scale [optional]
- * @return string the square root as a string, or <b>NULL</b> if
+ * @param int|null $scale [optional]
+ * @return string|null the square root as a string, or <b>NULL</b> if
  * <i>operand</i> is negative.
  */
-function bcsqrt ($operand, $scale = null) {}
+#[Pure]
+#[LanguageLevelTypeAware(["8.0" => "string"], default: "?string")]
+function bcsqrt (string $num, ?int $scale)
+{}
 
 /**
  * Set default scale parameter for all bc math functions
  * @link https://php.net/manual/en/function.bcscale.php
- * @param int $scale <p>
- * The scale factor. Since 7.3.0 can be omitted.
- * </p>
- * @return int|true <b>INT</b> since 7.3.0 and <b>TRUE</b> before.
+ * @param int $scale
+ * @return int|bool
  */
-function bcscale ($scale = null) {}
+#[LanguageLevelTypeAware(['7.3'=>'int'], default: 'bool')]
+#[PhpStormStubsElementAvailable(to: '7.4')]
+function bcscale (int $scale)
+{}
+
+/**
+ * Set default scale parameter for all bc math functions
+ * @link https://php.net/manual/en/function.bcscale.php
+ * @param int|null $scale
+ * @return int Returns the old scale when used as setter. Otherwise the current scale is returned.
+ */
+#[PhpStormStubsElementAvailable('8.0')]
+function bcscale (?int $scale = null): int
+{}
 
 /**
  * Compare two arbitrary precision numbers
  * @link https://php.net/manual/en/function.bccomp.php
- * @param string $left_operand <p>
+ * @param string $num1 <p>
  * The left operand, as a string.
  * </p>
- * @param string $right_operand <p>
+ * @param string $num2 <p>
  * The right operand, as a string.
  * </p>
- * @param int $scale [optional] <p>
+ * @param int|null $scale [optional] <p>
  * The optional <i>scale</i> parameter is used to set the
  * number of digits after the decimal place which will be used in the
  * comparison.
@@ -158,12 +236,14 @@ function bcscale ($scale = null) {}
  * <i>left_operand</i> is larger than the
  * <i>right_operand</i>, -1 otherwise.
  */
-function bccomp ($left_operand, $right_operand, $scale = 0) {}
+#[Pure]
+function bccomp (string $num1, string $num2, ?int $scale = 0): int
+{}
 
 /**
  * Raise an arbitrary precision number to another, reduced by a specified modulus
  * @link https://php.net/manual/en/function.bcpowmod.php
- * @param string $base <p>
+ * @param string $num <p>
  * The base, as an integral string (i.e. the scale has to be zero).
  * </p>
  * @param string $exponent <p>
@@ -173,7 +253,7 @@ function bccomp ($left_operand, $right_operand, $scale = 0) {}
  * @param string $modulus <p>
  * The modulus, as an integral string (i.e. the scale has to be zero).
  * </p>
- * @param int $scale [optional] <p>
+ * @param int|null $scale [optional] <p>
  * This optional parameter is used to set the number of digits after the
  * decimal place in the result. If omitted, it will default to the scale
  * set globally with the {@link bcscale()} function, or fallback to 0 if
@@ -182,4 +262,7 @@ function bccomp ($left_operand, $right_operand, $scale = 0) {}
  * @return string|null the result as a string, or <b>NULL</b> if <i>modulus</i>
  * is 0 or <i>exponent</i> is negative.
  */
-function bcpowmod ($base, $exponent, $modulus, $scale = 0) {}
+#[Pure]
+#[LanguageLevelTypeAware(["8.0" => "string"], default: "?string")]
+function bcpowmod (string $num, string $exponent, string $modulus, ?int $scale = 0)
+{}
