@@ -1,5 +1,9 @@
 <?php
 
+use JetBrains\PhpStorm\ArrayShape;
+use JetBrains\PhpStorm\Internal\LanguageLevelTypeAware;
+use JetBrains\PhpStorm\Pure;
+
 class CURLFile {
     public $name;
     public $mime;
@@ -9,11 +13,11 @@ class CURLFile {
      * Create a CURLFile object
      * @link https://secure.php.net/manual/en/curlfile.construct.php
      * @param string $filename <p>Path to the file which will be uploaded.</p>
-     * @param string $mimetype [optional] <p>Mimetype of the file.</p>
-     * @param string $postname [optional] <p>Name of the file.</p>
+     * @param string $mime_type [optional] <p>Mimetype of the file.</p>
+     * @param string $posted_filename [optional] <p>Name of the file.</p>
      * @since 5.5
      */
-    function __construct($filename, $mimetype = '', $postname = '') {
+    function __construct($filename, $mime_type = '', $posted_filename = '') {
     }
 
     /**
@@ -22,6 +26,7 @@ class CURLFile {
      * @return string Returns file name.
      * @since 5.5
      */
+    #[Pure]
     public function getFilename() {
     }
 
@@ -31,6 +36,7 @@ class CURLFile {
      * @return string Returns MIME type.
      * @since 5.5
      */
+    #[Pure]
     public function getMimeType() {
     }
 
@@ -40,25 +46,26 @@ class CURLFile {
      * @return string Returns file name for POST.
      * @since 5.5
      */
+    #[Pure]
     public function getPostFilename() {
     }
 
     /**
      * Set MIME type
      * @link https://secure.php.net/manual/en/curlfile.setmimetype.php
-     * @param string $mime
+     * @param string $mime_type
      * @since 5.5
      */
-    public function setMimeType($mime) {
+    public function setMimeType($mime_type) {
     }
 
     /**
      * Set file name for POST
      * https://secure.php.net/manual/en/curlfile.setpostfilename.php
-     * @param string $postname
+     * @param string $posted_filename
      * @since 5.5
      */
-    public function setPostFilename($postname) {
+    public function setPostFilename($posted_filename) {
     }
 
     /**
@@ -72,28 +79,31 @@ class CURLFile {
 /**
  * Initialize a cURL session
  * @link https://php.net/manual/en/function.curl-init.php
- * @param string $url [optional] <p>
+ * @param string|null $url [optional] <p>
  * If provided, the CURLOPT_URL option will be set
  * to its value. You can manually set this using the
  * curl_setopt function.
  * </p>
  * @return resource|false|CurlHandle a cURL handle on success, false on errors.
  */
-function curl_init ($url = null) {}
+#[LanguageLevelTypeAware(["8.0" => "CurlHandle|false"], default: "resource|false")]
+function curl_init (?string $url) {}
 
 /**
  * Copy a cURL handle along with all of its preferences
  * @link https://php.net/manual/en/function.curl-copy-handle.php
- * @param resource $ch
- * @return resource a new cURL handle.
+ * @param CurlHandle|resource $handle
+ * @return CurlHandle|resource|false a new cURL handle.
  */
-function curl_copy_handle ($ch) {}
+#[Pure]
+#[LanguageLevelTypeAware(["8.0" => "CurlHandle|false"], default: "resource|false")]
+function curl_copy_handle (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle) {}
 
 /**
  * Gets cURL version information
  * @link https://php.net/manual/en/function.curl-version.php
  * @param int $age [optional] Removed since version PHP 8.0.
- * @return array an associative array with the following elements:
+ * @return array|false an associative array with the following elements:
  * <tr valign="top">
  * <td>Indice</td>
  * <td>Value description</td>
@@ -135,12 +145,25 @@ function curl_copy_handle ($ch) {}
  * <td>An array of protocols names supported by cURL</td>
  * </tr>
  */
-function curl_version ($age = null) {}
+#[ArrayShape([
+    "version_number" => "string",
+    "version" => "string",
+    "ssl_version_number" => "int",
+    "ssl_version" => "string",
+    "libz_version" => "string",
+    "host" => "string",
+    "age" => "int",
+    "features" => "int",
+    "protocols" => "array",
+])]
+#[Pure]
+function curl_version ($age = null): array|false
+{}
 
 /**
  * Set an option for a cURL transfer
  * @link https://php.net/manual/en/function.curl-setopt.php
- * @param resource $ch
+ * @param CurlHandle|resource $handle
  * @param int $option <p>
  * The CURLOPT_XXX option to set.
  * </p>
@@ -149,7 +172,7 @@ function curl_version ($age = null) {}
  * </p>
  * <p>
  * value should be a bool for the
- * following values of the option parameter:
+ * following values of the option parameter:</p>
  * <table class="doctable informaltable">
  *
  * <thead>
@@ -158,7 +181,6 @@ function curl_version ($age = null) {}
  * <th>Set <em>value</em> to</th>
  * <th>Notes</th>
  * </tr>
- *
  * </thead>
  *
  * <tbody class="tbody">
@@ -595,7 +617,6 @@ function curl_version ($age = null) {}
  * <th>Set <em>value</em> to</th>
  * <th>Notes</th>
  * </tr>
- *
  * </thead>
  *
  * <tbody class="tbody">
@@ -1049,7 +1070,6 @@ function curl_version ($age = null) {}
  * <th>Set <code class="parameter">value</code> to</th>
  * <th>Notes</th>
  * </tr>
- *
  * </thead>
  *
  * <tbody class="tbody">
@@ -1472,7 +1492,6 @@ function curl_version ($age = null) {}
  * <th>Set <code class="parameter">value</code> to</th>
  * <th>Notes</th>
  * </tr>
- *
  * </thead>
  *
  * <tbody class="tbody">
@@ -1883,12 +1902,11 @@ function curl_version ($age = null) {}
  * <td style="vertical-align: top;">
  * </td>
  * </tr>
- *
  * </tbody>
  *
  * </table>
- * </p>
- * value should be an array for the following values of the option parameter:
+ * <p>
+ * value should be an array for the following values of the option parameter:</p>
  * <table class="doctable informaltable">
  *
  * <thead>
@@ -1897,7 +1915,6 @@ function curl_version ($age = null) {}
  * <th>Set <code class="parameter">value</code> to</th>
  * <th>Notes</th>
  * </tr>
- *
  * </thead>
  *
  * <tbody class="tbody">
@@ -1955,7 +1972,6 @@ function curl_version ($age = null) {}
  * <th>Option</th>
  * <th>Set <code class="parameter">value</code> to</th>
  * </tr>
- *
  * </thead>
  *
  * <tbody class="tbody">
@@ -2000,7 +2016,6 @@ function curl_version ($age = null) {}
  * <th>Option</th>
  * <th>Set <code class="parameter">value</code> to</th>
  * </tr>
- *
  * </thead>
  *
  * <tbody class="tbody">
@@ -2086,7 +2101,6 @@ function curl_version ($age = null) {}
  * <th>Option</th>
  * <th>Set <code class="parameter">value</code> to</th>
  * </tr>
- *
  * </thead>
  *
  * <tbody class="tbody">
@@ -2097,18 +2111,18 @@ function curl_version ($age = null) {}
  * handle to use the data from the shared handle.
  * </td>
  * </tr>
- *
  * </tbody>
  *
  * </table>
  * @return bool true on success or false on failure.
  */
-function curl_setopt ($ch, $option, $value) {}
+function curl_setopt (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle, int $option, mixed $value): bool
+{}
 
 /**
  * Set multiple options for a cURL transfer
  * @link https://php.net/manual/en/function.curl-setopt-array.php
- * @param resource $ch
+ * @param CurlHandle|resource $handle
  * @param array $options <p>
  * An array specifying which options to set and their values.
  * The keys should be valid curl_setopt constants or
@@ -2119,19 +2133,20 @@ function curl_setopt ($ch, $option, $value) {}
  * future options in the options array.
  * @since 5.1.3
  */
-function curl_setopt_array ($ch, array $options) {}
+function curl_setopt_array (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle, array $options): bool
+{}
 
 /**
  * (PHP 5 &gt;=5.5.0)<br/>
  * Close a cURL share handle
  * @link https://secure.php.net/manual/en/function.curl-share-close.php
- * @param resource $sh <p>
+ * @param CurlShareHandle|resource $share_handle <p>
  * A cURL share handle returned by  {@link https://secure.php.net/manual/en/function.curl-share-init.php curl_share_init()}
  * </p>
  * @return void
  * @since 5.5
  */
-function curl_share_close ($sh) {}
+function curl_share_close (#[LanguageLevelTypeAware(["8.0" => "CurlShareHandle"], default: "resource")] $share_handle): void {}
 
 /**
  * (PHP 5 &gt;=5.5.0)<br/>
@@ -2140,13 +2155,15 @@ function curl_share_close ($sh) {}
  * @return resource|CurlShareHandle Returns resource of type "cURL Share Handle".
  * @since 5.5
  */
-function curl_share_init () {}
+#[LanguageLevelTypeAware(["8.0" => "CurlShareHandle"], default: "resource")]
+function curl_share_init()
+{}
 
 /**
  * (PHP 5 &gt;=5.5.0)<br/>
  * Set an option for a cURL share handle.
  * @link https://secure.php.net/manual/en/function.curl-share-setopt.php
- * @param resource $sh <p>
+ * @param CurlShareHandle|resource $share_handle <p>
  * A cURL share handle returned by  {@link https://secure.php.net/manual/en/function.curl-share-init.php curl_share_init()}.
  * </p>
  * @param int $option <table>
@@ -2156,7 +2173,6 @@ function curl_share_init () {}
  * <th>Option</th>
  * <th>Description</th>
  * </tr>
- *
  * </thead>
  *
  * <tbody>
@@ -2184,7 +2200,6 @@ function curl_share_init () {}
  * <th>Value</th>
  * <th>Description</th>
  * </tr>
- *
  * </thead>
  *
  * <tbody class="tbody">
@@ -2221,49 +2236,55 @@ function curl_share_init () {}
  * Returns <b>TRUE</b> on success or <b>FALSE</b> on failure.
  * @since 5.5
  */
-function curl_share_setopt ($sh, $option, $value ) {}
+function curl_share_setopt (#[LanguageLevelTypeAware(["8.0" => "CurlShareHandle"], default: "resource")] $share_handle, int $option, mixed $value ): bool
+{}
 
 /**
  * (PHP 5 &gt;=5.5.0)<br/>
  * Return string describing the given error code
  * @link https://secure.php.net/manual/en/function.curl-strerror.php
- * @param int $errornum <p>
+ * @param int $error_code <p>
  * One of the {@link https://curl.haxx.se/libcurl/c/libcurl-errors.html &nbsp;cURL error codes} constants.
  * </p>
  * @return string|null Returns error description or <b>NULL</b> for invalid error code.
  * @since 5.5
  */
-function curl_strerror ($errornum ) {}
+#[Pure]
+function curl_strerror (int $error_code): ?string
+{}
 
 /**
  * (PHP 5 &gt;=5.5.0)<br/>
  * Decodes the given URL encoded string
  * @link https://secure.php.net/manual/en/function.curl-unescape.php
- * @param resource $ch <p>A cURL handle returned by
+ * @param CurlHandle|resource $handle <p>A cURL handle returned by
  * {@link https://secure.php.net/manual/en/function.curl-init.php curl_init()}.</p>
- * @param string $str <p>
+ * @param string $string <p>
  * The URL encoded string to be decoded.
  * </p>
  * @return string|false Returns decoded string or FALSE on failure.
  * @since 5.5
  */
-function  curl_unescape ($ch, $str)  {}
+#[Pure]
+function  curl_unescape (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle, string $string): string|false
+{}
 /**
  * Perform a cURL session
  * @link https://php.net/manual/en/function.curl-exec.php
- * @param resource $ch
+ * @param CurlHandle|resource $handle
  * @return string|bool true on success or false on failure. However, if the CURLOPT_RETURNTRANSFER
  * option is set, it will return the result on success, false on failure.
  */
-function curl_exec ($ch) {}
+function curl_exec (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle): string|bool
+{}
 
 /**
  * Get information regarding a specific transfer
  * @link https://php.net/manual/en/function.curl-getinfo.php
- * @param resource $ch
- * @param int $opt [optional] <p>
+ * @param CurlHandle|resource $handle
+ * @param int|null $option [optional] <p>
  * This may be one of the following constants:
- * CURLINFO_EFFECTIVE_URL - Last effective URL
+ * CURLINFO_EFFECTIVE_URL - Last effective URL</p>
  * @return mixed If opt is given, returns its value as a string.
  * Otherwise, returns an associative array with the following elements
  * (which correspond to opt):
@@ -2288,103 +2309,119 @@ function curl_exec ($ch) {}
  * "starttransfer_time"
  * "redirect_time"
  */
-function curl_getinfo ($ch, $opt = null) {}
+#[Pure]
+function curl_getinfo (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle, ?int $option): mixed
+{}
 
 /**
  * Return a string containing the last error for the current session
  * @link https://php.net/manual/en/function.curl-error.php
- * @param resource $ch
+ * @param CurlHandle|resource $handle
  * @return string the error message or '' (the empty string) if no
  * error occurred.
  */
-function curl_error ($ch) {}
+#[Pure]
+function curl_error (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle): string
+{}
 
 /**
  * Return the last error number
  * @link https://php.net/manual/en/function.curl-errno.php
- * @param resource $ch
+ * @param CurlHandle|resource $handle
  * @return int the error number or 0 (zero) if no error
  * occurred.
  */
-function curl_errno ($ch) {}
+#[Pure]
+function curl_errno (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle): int
+{}
 
 /**
  * URL encodes the given string
  * @link https://secure.php.net/manual/en/function.curl-escape.php
- * @param resource $ch <p>
+ * @param CurlHandle|resource $handle <p>
  * A cURL handle returned by
  * {@link https://secure.php.net/manual/en/function.curl-init.php curl_init()}.</p>
- * @param string $str <p>
+ * @param string $string <p>
  * The string to be encoded.</p>
  * @return string|false Returns escaped string or FALSE on failure.
  * @since 5.5
  */
-function curl_escape($ch, $str) {}
+#[Pure]
+function curl_escape(#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle, string $string): string|false
+{}
 
 /**
  * (PHP 5 >= 5.5.0) <br/>
  * Create a CURLFile object
  * @link https://secure.php.net/manual/en/curlfile.construct.php
  * @param string $filename <p> Path to the file which will be uploaded.</p>
- * @param string $mimetype [optional] <p>Mimetype of the file.</p>
- * @param string $postname [optional] <p>Name of the file.</p>
+ * @param string|null $mime_type [optional] <p>Mimetype of the file.</p>
+ * @param string|null $posted_filename [optional] <p>Name of the file.</p>
  * @return CURLFile
  * Returns a {@link https://secure.php.net/manual/en/class.curlfile.php CURLFile} object.
  * @since 5.5
  */
-function curl_file_create($filename, $mimetype = '', $postname = '') {}
+#[Pure]
+function curl_file_create(string $filename, ?string $mime_type = '', ?string $posted_filename = ''): CURLFile
+{}
 
 /**
  * Close a cURL session
  * @link https://php.net/manual/en/function.curl-close.php
- * @param resource $ch
+ * @param CurlHandle|resource $handle
  * @return void
  */
-function curl_close ($ch) {}
+function curl_close (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle): void {}
 
 /**
  * Returns a new cURL multi handle
  * @link https://php.net/manual/en/function.curl-multi-init.php
- * @return resource|false|CurlMultiHandle a cURL multi handle resource on success, false on failure.
+ * @return resource|CurlMultiHandle|false a cURL multi handle resource on success, false on failure.
  */
-function curl_multi_init () {}
+#[LanguageLevelTypeAware(["8.0" => "CurlMultiHandle"], default: "resource")]
+function curl_multi_init (): CurlMultiHandle
+{}
 
 /**
  * Add a normal cURL handle to a cURL multi handle
  * @link https://php.net/manual/en/function.curl-multi-add-handle.php
- * @param resource $mh
- * @param resource $ch
+ * @param CurlMultiHandle|resource $multi_handle
+ * @param CurlHandle|resource $handle
  * @return int 0 on success, or one of the CURLM_XXX errors
  * code.
  */
-function curl_multi_add_handle ($mh, $ch) {}
+function curl_multi_add_handle (#[LanguageLevelTypeAware(["8.0" => "CurlMultiHandle"], default: "resource")] $multi_handle, #[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle): int
+{}
 
 /**
  * Remove a multi handle from a set of cURL handles
  * @link https://php.net/manual/en/function.curl-multi-remove-handle.php
- * @param resource $mh
- * @param resource $ch
+ * @param CurlMultiHandle|resource $multi_handle
+ * @param CurlHandle|resource $handle
  * @return int|false On success, returns one of the CURLM_XXX error codes, false on failure.
  */
-function curl_multi_remove_handle ($mh, $ch) {}
+#[LanguageLevelTypeAware(["8.0" => "int"], default: "int|false")]
+function curl_multi_remove_handle (#[LanguageLevelTypeAware(["8.0" => "CurlMultiHandle"], default: "resource")] $multi_handle, #[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")]  $handle)
+{}
 
 /**
  * Wait for activity on any curl_multi connection
  * @link https://php.net/manual/en/function.curl-multi-select.php
- * @param resource $mh
+ * @param CurlMultiHandle|resource $multi_handle
  * @param float $timeout [optional] <p>
  * Time, in seconds, to wait for a response.
  * </p>
  * @return int On success, returns the number of descriptors contained in,
  * the descriptor sets. On failure, this function will return -1 on a select failure or timeout (from the underlying select system call).
  */
-function curl_multi_select ($mh, $timeout = 1.0) {}
+function curl_multi_select (#[LanguageLevelTypeAware(["8.0" => "CurlMultiHandle"], default: "resource")] $multi_handle, float $timeout = 1.0): int
+{}
 
 /**
  * (PHP 5 &gt;=5.5.0)<br/>
  * Set an option for the cURL multi handle
  * @link https://secure.php.net/manual/en/function.curl-multi-setopt.php
- * @param resource $mh
+ * @param CurlMultiHandle|resource $multi_handle
  * @param int $option <p>
  * One of the <b>CURLMOPT_*</b> constants.
  * </p>
@@ -2401,7 +2438,6 @@ function curl_multi_select ($mh, $timeout = 1.0) {}
  * <th>Option</th>
  * <th>Set <em><code class="parameter">value</code></em> to</th>
  * </tr>
- *
  * </thead>
  *
  * <tbody>
@@ -2431,118 +2467,153 @@ function curl_multi_select ($mh, $timeout = 1.0) {}
  * @return bool Returns TRUE on success or FALSE on failure.
  * @since 5.5
  */
-function curl_multi_setopt ($mh, $option, $value) {}
+function curl_multi_setopt (#[LanguageLevelTypeAware(["8.0" => "CurlMultiHandle"], default: "resource")] $multi_handle, int $option, mixed $value): bool
+{}
 
 /**
  * (PHP 5 &gt;=5.5.0)<br/>
  * Return string describing error code
  * @link https://secure.php.net/manual/en/function.curl-multi-strerror.php
- * @param int $errornum <p>
+ * @param int $error_code <p>
  * One of the {@link https://curl.haxx.se/libcurl/c/libcurl-errors.html CURLM error codes} constants.
  * </p>
  * @return string|null Returns error string for valid error code, NULL otherwise.
  * @since 5.5
  */
-function curl_multi_strerror ($errornum) {}
+function curl_multi_strerror (int $error_code): ?string
+{}
 
 /**
  * (PHP 5 &gt;=5.5.0)<br/>
  * Pause and unpause a connection
  * @link https://secure.php.net/manual/en/function.curl-pause.php
- * @param resource $ch
+ * @param CurlHandle|resource $handle
  * <p>A cURL handle returned by {@link https://secure.php.net/manual/en/function.curl-init.php curl_init()}.</p>
- * @param int $bitmask <p>One of <b>CURLPAUSE_*</b> constants.</p>
+ * @param int $flags <p>One of <b>CURLPAUSE_*</b> constants.</p>
  * @return int Returns an error code (<b>CURLE_OK</b> for no error).
  * @since 5.5
  */
-function curl_pause ($ch, $bitmask ) {}
+function curl_pause (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle, int $flags): int
+{}
 
 /**
  * (PHP 5 &gt;=5.5.0)<br/>
  * Reset all options of a libcurl session handle
  * @link https://secure.php.net/manual/en/function.curl-reset.php
- * @param resource $ch <p>A cURL handle returned by
+ * @param CurlHandle|resource $handle <p>A cURL handle returned by
  * {@link https://secure.php.net/manual/en/function.curl-init.php curl_init()}.</p>
  * @return void
  * @since 5.5
  */
-function curl_reset ($ch) {}
+function curl_reset (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle): void {}
 
 /**
  * Run the sub-connections of the current cURL handle
  * @link https://php.net/manual/en/function.curl-multi-exec.php
- * @param resource $mh
+ * @param CurlMultiHandle|resource $multi_handle
  * @param int &$still_running <p>
  * A reference to a flag to tell whether the operations are still running.
  * </p>
  * @return int A cURL code defined in the cURL Predefined Constants.
- * </p>
  * <p>
  * This only returns errors regarding the whole multi stack. There might still have
  * occurred problems on individual transfers even when this function returns
  * CURLM_OK.
+ * </p>
  */
-function curl_multi_exec ($mh, &$still_running) {}
+function curl_multi_exec (#[LanguageLevelTypeAware(["8.0" => "CurlMultiHandle"], default: "resource")] $multi_handle, &$still_running): int
+{}
 
 /**
  * Return the content of a cURL handle if <constant>CURLOPT_RETURNTRANSFER</constant> is set
  * @link https://php.net/manual/en/function.curl-multi-getcontent.php
- * @param resource $ch
- * @return string Return the content of a cURL handle if CURLOPT_RETURNTRANSFER is set.
+ * @param CurlHandle|resource $handle
+ * @return null|string Return the content of a cURL handle if CURLOPT_RETURNTRANSFER is set.
  */
-function curl_multi_getcontent ($ch) {}
+#[Pure]
+function curl_multi_getcontent (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle): ?string
+{}
 
 /**
  * Get information about the current transfers
  * @link https://php.net/manual/en/function.curl-multi-info-read.php
- * @param resource $mh
- * @param int &$msgs_in_queue [optional] <p>
+ * @param CurlMultiHandle|resource $multi_handle
+ * @param int &$queued_messages [optional] <p>
  * Number of messages that are still in the queue
  * </p>
  * @return array|false On success, returns an associative array for the message, false on failure.
  */
-function curl_multi_info_read ($mh, &$msgs_in_queue = null) {}
+#[Pure]
+function curl_multi_info_read (#[LanguageLevelTypeAware(["8.0" => "CurlMultiHandle"], default: "resource")] $multi_handle, &$queued_messages): array|false
+{}
 
 /**
  * Close a set of cURL handles
  * @link https://php.net/manual/en/function.curl-multi-close.php
- * @param resource $mh
+ * @param CurlMultiHandle|resource $multi_handle
  * @return void
  */
-function curl_multi_close ($mh) {}
+function curl_multi_close (#[LanguageLevelTypeAware(["8.0" => "CurlMultiHandle"], default: "resource")] $multi_handle): void {}
 
 /**
- * @param resource $mh
- * @since 7.1
+ * Return the last multi curl error number
+ * @param CurlMultiHandle|resource $multi_handle
  * @return int
+ * @since 7.1
  */
-function curl_multi_errno($mh) {}
+#[Pure]
+function curl_multi_errno(#[LanguageLevelTypeAware(["8.0" => "CurlMultiHandle"], default: "resource")] $multi_handle): int
+{}
 
 /**
- * @param resource $rh
- * @since 7.1
+ * Return the last share curl error number
+ * @param CurlMultiHandle|resource $share_handle
  * @return int
- */
-function curl_share_errno($rh) {}
-
-/**
- * @param int $errno
  * @since 7.1
- * @return string
  */
-function curl_share_strerror($errno){}
+#[Pure]
+function curl_share_errno(#[LanguageLevelTypeAware(["8.0" => "CurlShareHandle"], default: "resource")]  $share_handle): int
+{}
+
+/**
+ * Return string describing the given error code
+ * @param int $error_code
+ * @return string|null
+ * @since 7.1
+ */
+#[Pure]
+function curl_share_strerror(int $error_code): ?string
+{}
 
 /**
  * @since 8.0
  */
-final class CurlHandle{}
+final class CurlHandle{
+    /**
+     * Cannot directly construct CurlHandle, use curl_init() instead
+     * @see curl_init()
+     */
+    private function __construct(){}
+}
 
 /**
  * @since 8.0
  */
-final class CurlMultiHandle{}
+final class CurlMultiHandle{
+    /**
+     * Cannot directly construct CurlMultiHandle, use curl_multi_init() instead
+     * @see curl_multi_init()
+     */
+    private function __construct(){}
+}
 
 /**
  * @since 8.0
  */
-final class CurlShareHandle{}
+final class CurlShareHandle{
+    /**
+     * Cannot directly construct CurlShareHandle, use curl_share_init() instead
+     * @see  curl_share_init()
+     */
+    private function __construct(){}
+}
