@@ -1,6 +1,7 @@
 <?php
 
 // Start of enchant v.1.1.0
+use JetBrains\PhpStorm\Deprecated;
 
 /**
  * (PHP 5 &gt;= 5.3.0, PECL enchant &gt;= 0.1.0 )<br/>
@@ -11,51 +12,57 @@
 function enchant_broker_init () {}
 
 /**
- * (PHP 5 &gt;= 5.3.0, PECL enchant &gt;= 0.1.0 )<br/>
- * Free the broker resource and its dictionnaries
+ * Free the broker resource and its dictionaries
  * @link https://php.net/manual/en/function.enchant-broker-free.php
- * @param resource $broker <p>
+ * @param resource|EnchantBroker $broker <p>
  * Broker resource
  * </p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
- * @deprecated 8.0 Unset the object instead
+ * @since 5.3
  */
+#[Deprecated(reason: "Unset the object instead", since: '8.0')]
 function enchant_broker_free ($broker) {}
 
 /**
  * (PHP 5 &gt;= 5.3.0, PECL enchant &gt;= 0.1.0 )<br/>
  * Returns the last error of the broker
  * @link https://php.net/manual/en/function.enchant-broker-get-error.php
- * @param resource $broker <p>
+ * @param resource|EnchantBroker $broker <p>
  * Broker resource.
  * </p>
- * @return string Return the msg string if an error was found or <b>FALSE</b>
+ * @return string|false Return the msg string if an error was found or <b>FALSE</b>
  */
 function enchant_broker_get_error ($broker) {}
 
 /**
- * @param $broker
- * @param $name
- * @param $value
- * @deprecated 8.0
+ * Set the directory path for a given backend
+ * @link https://www.php.net/manual/en/function.enchant-broker-set-dict-path.php
+ * @param resource|EnchantBroker $broker
+ * @param int $dict_type
+ * @param string $value
+ * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function enchant_broker_set_dict_path ($broker, $name, $value) {}
+#[Deprecated(since: '8.0', reason: 'Relying on this function is highly discouraged.')]
+function enchant_broker_set_dict_path ($broker, int $dict_type, string $value) {}
 
 /**
- * @param $broker
- * @param $name
- * @deprecated 8.0
+ * Get the directory path for a given backend
+ * @link https://www.php.net/manual/en/function.enchant-broker-get-dict-path.php
+ * @param resource|EnchantBroker $broker
+ * @param int $dict_type
+ * @return string|false
  */
-function enchant_broker_get_dict_path ($broker, $name) {}
+#[Deprecated(since: '8.0', reason: 'Relying on this function is highly discouraged.')]
+function enchant_broker_get_dict_path ($broker, $dict_type) {}
 
 /**
  * (PHP 5 &gt;= 5.3.0, PECL enchant &gt;= 1.0.1)<br/>
  * Returns a list of available dictionaries
  * @link https://php.net/manual/en/function.enchant-broker-list-dicts.php
- * @param resource $broker <p>
+ * @param resource|EnchantBroker $broker <p>
  * Broker resource
  * </p>
- * @return mixed <b>TRUE</b> on success or <b>FALSE</b> on failure.
+ * @return array Returns an array of available dictionaries with their details.
  */
 function enchant_broker_list_dicts ($broker) {}
 
@@ -63,7 +70,7 @@ function enchant_broker_list_dicts ($broker) {}
  * (PHP 5 &gt;= 5.3.0, PECL enchant &gt;= 0.1.0 )<br/>
  * create a new dictionary using a tag
  * @link https://php.net/manual/en/function.enchant-broker-request-dict.php
- * @param resource $broker <p>
+ * @param resource|EnchantBroker $broker <p>
  * Broker resource
  * </p>
  * @param string $tag <p>
@@ -77,7 +84,7 @@ function enchant_broker_request_dict ($broker, $tag) {}
  * (PHP 5 &gt;= 5.3.0, PECL enchant &gt;= 0.1.0 )<br/>
  * creates a dictionary using a PWL file
  * @link https://php.net/manual/en/function.enchant-broker-request-pwl-dict.php
- * @param resource $broker <p>
+ * @param resource|EnchantBroker $broker <p>
  * Broker resource
  * </p>
  * @param string $filename <p>
@@ -91,19 +98,19 @@ function enchant_broker_request_pwl_dict ($broker, $filename) {}
  * (PHP 5 &gt;= 5.3.0, PECL enchant &gt;= 0.1.0 )<br/>
  * Free a dictionary resource
  * @link https://php.net/manual/en/function.enchant-broker-free-dict.php
- * @param resource $dict <p>
+ * @param resource|EnchantDictionary $dict <p>
  * Dictionary resource.
  * </p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
- * @deprecated 8.0 Unset the object instead
  */
+#[Deprecated("Unset the object instead",since: '8.0')]
 function enchant_broker_free_dict ($dict) {}
 
 /**
  * (PHP 5 &gt;= 5.3.0, PECL enchant &gt;= 0.1.0 )<br/>
  * Whether a dictionary exists or not. Using non-empty tag
  * @link https://php.net/manual/en/function.enchant-broker-dict-exists.php
- * @param resource $broker <p>
+ * @param resource|EnchantBroker $broker <p>
  * Broker resource
  * </p>
  * @param string $tag <p>
@@ -117,7 +124,7 @@ function enchant_broker_dict_exists ($broker, $tag) {}
  * (PHP 5 &gt;= 5.3.0, PECL enchant &gt;= 0.1.0 )<br/>
  * Declares a preference of dictionaries to use for the language
  * @link https://php.net/manual/en/function.enchant-broker-set-ordering.php
- * @param resource $broker <p>
+ * @param resource|EnchantBroker $broker <p>
  * Broker resource
  * </p>
  * @param string $tag <p>
@@ -136,7 +143,7 @@ function enchant_broker_set_ordering ($broker, $tag, $ordering) {}
  * (PHP 5 &gt;= 5.3.0, PECL enchant &gt;= 0.1.0)<br/>
  * Enumerates the Enchant providers
  * @link https://php.net/manual/en/function.enchant-broker-describe.php
- * @param resource $broker <p>
+ * @param resource|EnchantBroker $broker <p>
  * Broker resource
  * </p>
  * @return array|false
@@ -147,7 +154,7 @@ function enchant_broker_describe ($broker) {}
  * (PHP 5 &gt;= 5.3.0, PECL enchant &gt;= 0.1.0 )<br/>
  * Check whether a word is correctly spelled or not
  * @link https://php.net/manual/en/function.enchant-dict-check.php
- * @param resource $dict <p>
+ * @param resource|EnchantDictionary $dict <p>
  * Dictionary resource
  * </p>
  * @param string $word <p>
@@ -161,7 +168,7 @@ function enchant_dict_check ($dict, $word) {}
  * (PHP 5 &gt;= 5.3.0, PECL enchant &gt;= 0.1.0 )<br/>
  * Will return a list of values if any of those pre-conditions are not met
  * @link https://php.net/manual/en/function.enchant-dict-suggest.php
- * @param resource $dict <p>
+ * @param resource|EnchantDictionary $dict <p>
  * Dictionary resource
  * </p>
  * @param string $word <p>
@@ -182,24 +189,44 @@ function enchant_dict_suggest ($dict, $word) {}
  * The word to add
  * </p>
  * @return void
- * @deprecated 8.0 Use {@link enchant_dict_add} instead
+ * @see enchant_dict_add()
  */
+#[Deprecated(
+  reason: 'Use enchant_dict_add instead',
+  replacement: 'enchant_dict_add(%parameter0%, %parameter1%)',
+  since: '8.0'
+)]
 function enchant_dict_add_to_personal ($dict, $word) {}
 
 /**
  * (PHP 5 &gt;= 5.3.0, PECL enchant &gt;= 0.1.0 )<br/>
  * add 'word' to this spell-checking session
  * @link https://php.net/manual/en/function.enchant-dict-add-to-session.php
- * @param resource $dict <p>
+ * @param resource|EnchantDictionary $dict <p>
  * Dictionary resource
  * </p>
  * @param string $word <p>
  * The word to add
  * </p>
- * @return void <b>TRUE</b> on success or <b>FALSE</b> on failure.
+ * @return void
  */
 function enchant_dict_add_to_session ($dict, $word) {}
 
+/**
+ * (PHP 8)<br/>
+ * Add a word to personal word list
+ * @link https://php.net/manual/en/function.enchant-dict-add.php
+ * @param EnchantDictionary $dictionary <p>
+ * An Enchant dictionary returned by enchant_broker_request_dict() or enchant_broker_request_pwl_dict().
+ * </p>
+ * @param string $word <p>
+ * The word to add
+ * </p>
+ * @return void
+ * @since 8.0
+ */
+function enchant_dict_add ($dictionary, $word) {}
+
 /**
  * (PHP 5 &gt;= 5.3.0, PECL enchant &gt;= 0.1.0 )<br/>
  * whether or not 'word' exists in this spelling-session
@@ -211,15 +238,20 @@ function enchant_dict_add_to_session ($dict, $word) {}
  * The word to lookup
  * </p>
  * @return bool <b>TRUE</b> if the word exists or <b>FALSE</b>
- * @deprecated 8.0 Use {@enchant_dict_is_added} instead.
+ * @see enchant_dict_is_added
  */
+#[Deprecated(
+  reason: 'Use enchant_dict_is_added instead',
+  replacement: 'enchant_dict_is_added(%parameter0%, %parameter1%)',
+  since: '8.0'
+)]
 function enchant_dict_is_in_session ($dict, $word) {}
 
 /**
  * (PHP 5 &gt;= 5.3.0, PECL enchant &gt;= 0.1.0 )<br/>
  * Add a correction for a word
  * @link https://php.net/manual/en/function.enchant-dict-store-replacement.php
- * @param resource $dict <p>
+ * @param resource|EnchantDictionary $dict <p>
  * Dictionary resource
  * </p>
  * @param string $mis <p>
@@ -236,21 +268,36 @@ function enchant_dict_store_replacement ($dict, $mis, $cor) {}
  * (PHP 5 &gt;= 5.3.0, PECL enchant &gt;= 0.1.0 )<br/>
  * Returns the last error of the current spelling-session
  * @link https://php.net/manual/en/function.enchant-dict-get-error.php
- * @param resource $dict <p>
+ * @param resource|EnchantDictionary $dict <p>
  * Dictinaray resource
  * </p>
- * @return string the error message as string or <b>FALSE</b> if no error occurred.
+ * @return string|false the error message as string or <b>FALSE</b> if no error occurred.
  */
 function enchant_dict_get_error ($dict) {}
 
+/**
+ * (PHP 8)<br/>
+ * Whether or not 'word' exists in this spelling-session
+ * @link https://php.net/manual/en/function.enchant-dict-is-added.php
+ * @param EnchantDictionary $dictionary <p>
+ * An Enchant dictionary returned by enchant_broker_request_dict() or enchant_broker_request_pwl_dict().
+ * </p>
+ * @param string $word <p>
+ * The word to lookup
+ * </p>
+ * @return bool <b>TRUE</b> if the word exists or <b>FALSE</b>
+ * @since 8.0
+ */
+function enchant_dict_is_added ($dictionary, $word) {}
+
 /**
  * (PHP 5 &gt;= 5.3.0, PECL enchant &gt;= 0.1.0 )<br/>
  * Describes an individual dictionary
  * @link https://php.net/manual/en/function.enchant-dict-describe.php
- * @param resource $dict <p>
+ * @param resource|EnchantDictionary $dict <p>
  * Dictionary resource
  * </p>
- * @return mixed <b>TRUE</b> on success or <b>FALSE</b> on failure.
+ * @return array Returns the details of the dictionary.
  */
 function enchant_dict_describe ($dict) {}
 
@@ -258,19 +305,19 @@ function enchant_dict_describe ($dict) {}
  * (PHP 5 &gt;= 5.3.0, PECL enchant:0.2.0-1.0.1)<br/>
  * Check the word is correctly spelled and provide suggestions
  * @link https://php.net/manual/en/function.enchant-dict-quick-check.php
- * @param resource $dict <p>
+ * @param resource|EnchantDictionary $dict <p>
  * Dictionary resource
  * </p>
  * @param string $word <p>
  * The word to check
  * </p>
- * @param array &$suggestions [optional] <p>
+ * @param null|array &$suggestions [optional] <p>
  * If the word is not correctly spelled, this variable will
  * contain an array of suggestions.
  * </p>
  * @return bool <b>TRUE</b> if the word is correctly spelled or <b>FALSE</b>
  */
-function enchant_dict_quick_check ($dict, $word, array &$suggestions = null) {}
+function enchant_dict_quick_check ($dict, $word, ?array &$suggestions = null) {}
 
 /**
  * @deprecated 8.0
