@@ -1,6 +1,8 @@
 <?php
 
 // Start of gmp v.
+use JetBrains\PhpStorm\Deprecated;
+use JetBrains\PhpStorm\Pure;
 
 /**
  * Create GMP number
@@ -21,6 +23,7 @@
  * </p>
  * @return resource|GMP A GMP number resource.
  */
+#[Pure]
 function gmp_init ($number, $base = 0) {}
 
 /**
@@ -31,6 +34,7 @@ function gmp_init ($number, $base = 0) {}
  * </p>
  * @return int An integer value of <i>gmpnumber</i>.
  */
+#[Pure]
 function gmp_intval ($gmpnumber) {}
 
 /**
@@ -39,7 +43,7 @@ function gmp_intval ($gmpnumber) {}
  * The seed to be set for the {@see gmp_random()}, {@see gmp_random_bits()}, and {@see gmp_random_range()} functions.
  * </p>
  * Either a GMP number resource in PHP 5.5 and earlier, a GMP object in PHP 5.6 and later, or a numeric string provided that it is possible to convert the latter to a number.
- * @return mixed Returns NULL on success.
+ * @return null|false Returns NULL on success.
  * @since 7.0
  */
 function gmp_random_seed ($seed ) {}
@@ -49,7 +53,7 @@ function gmp_random_seed ($seed ) {}
  * @param resource|string|GMP $gmpnumber <p>
  * The GMP number that will be converted to a string.
  * </p>
- * It can be either a GMP number resource, or a
+ * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @param int $base [optional] <p>
  * The base of the returned number. The default base is 10.
@@ -57,6 +61,7 @@ function gmp_random_seed ($seed ) {}
  * </p>
  * @return string The number, as a string.
  */
+#[Pure]
 function gmp_strval ($gmpnumber, $base = 10) {}
 
 /**
@@ -65,15 +70,16 @@ function gmp_strval ($gmpnumber, $base = 10) {}
  * @param resource|string|GMP $a <p>
  * A number that will be added.
  * </p>
- * It can be either a GMP number resource, or a
+ * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @param resource|string|GMP $b <p>
  * A number that will be added.
  * </p>
- * It can be either a GMP number resource, or a
+ * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return resource|GMP A GMP number representing the sum of the arguments.
  */
+#[Pure]
 function gmp_add ($a, $b) {}
 
 /**
@@ -82,15 +88,16 @@ function gmp_add ($a, $b) {}
  * @param resource|string|GMP $a <p>
  * The number being subtracted from.
  * </p>
- * It can be either a GMP number resource, or a
+ * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @param resource|string|GMP $b <p>
  * The number subtracted from <i>a</i>.
  * </p>
- * It can be either a GMP number resource, or a
+ * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return resource|GMP A GMP number resource.
  */
+#[Pure]
 function gmp_sub ($a, $b) {}
 
 /**
@@ -99,15 +106,16 @@ function gmp_sub ($a, $b) {}
  * @param resource|string|GMP $a <p>
  * A number that will be multiplied by <i>b</i>.
  * </p>
- * It can be either a GMP number resource, or a
+ * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @param resource|string|GMP $b <p>
  * A number that will be multiplied by <i>a</i>.
  * </p>
- * It can be either a GMP number resource, or a
+ * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return resource|GMP A GMP number resource.
  */
+#[Pure]
 function gmp_mul ($a, $b) {}
 
 /**
@@ -116,12 +124,12 @@ function gmp_mul ($a, $b) {}
  * @param resource|string|GMP $n <p>
  * The number being divided.
  * </p>
- * It can be either a GMP number resource, or a
+ * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @param resource|string|GMP $d <p>
  * The number that <i>n</i> is being divided by.
  * </p>
- * It can be either a GMP number resource, or a
+ * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @param int $round [optional] <p>
  * See the <b>gmp_div_q</b> function for description
@@ -132,6 +140,7 @@ function gmp_mul ($a, $b) {}
  * division) and the second being (n - [n/d] * d)
  * (the remainder of the division).
  */
+#[Pure]
 function gmp_div_qr ($n, $d, $round = GMP_ROUND_ZERO) {}
 
 /**
@@ -140,21 +149,22 @@ function gmp_div_qr ($n, $d, $round = GMP_ROUND_ZERO) {}
  * @param resource|string|GMP $a <p>
  * The number being divided.
  * </p>
- * It can be either a GMP number resource, or a
+ * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @param resource|string|GMP $b <p>
  * The number that <i>a</i> is being divided by.
  * </p>
- * It can be either a GMP number resource, or a
+ * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @param int $round [optional] <p>
  * The result rounding is defined by the
  * <i>round</i>, which can have the following
  * values:
  * <b>GMP_ROUND_ZERO</b>: The result is truncated
- * towards 0.
+ * towards 0.</p>
  * @return resource|GMP A GMP number resource.
  */
+#[Pure]
 function gmp_div_q ($a, $b, $round = GMP_ROUND_ZERO) {}
 
 /**
@@ -163,12 +173,12 @@ function gmp_div_q ($a, $b, $round = GMP_ROUND_ZERO) {}
  * @param resource|string|GMP $n <p>
  * The number being divided.
  * </p>
- * It can be either a GMP number resource, or a
+ * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @param resource|string|GMP $d <p>
  * The number that <i>n</i> is being divided by.
  * </p>
- * It can be either a GMP number resource, or a
+ * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @param int $round [optional] <p>
  * See the <b>gmp_div_q</b> function for description
@@ -176,6 +186,7 @@ function gmp_div_q ($a, $b, $round = GMP_ROUND_ZERO) {}
  * </p>
  * @return resource|GMP The remainder, as a GMP number.
  */
+#[Pure]
 function gmp_div_r ($n, $d, $round = GMP_ROUND_ZERO) {}
 
 /**
@@ -184,35 +195,37 @@ function gmp_div_r ($n, $d, $round = GMP_ROUND_ZERO) {}
  * @param resource|string|GMP $a <p>
  * The number being divided.
  * </p>
- * It can be either a GMP number resource, or a
+ * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @param resource|string|GMP $b <p>
  * The number that <i>a</i> is being divided by.
  * </p>
- * It can be either a GMP number resource, or a
+ * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @param int $round [optional] <p>
  * The result rounding is defined by the
  * <i>round</i>, which can have the following
  * values:
  * <b>GMP_ROUND_ZERO</b>: The result is truncated
- * towards 0.
+ * towards 0.</p>
  * @return resource|GMP A GMP number resource.
  */
+#[Pure]
 function gmp_div ($a, $b, $round = GMP_ROUND_ZERO) {}
 
 /**
  * Modulo operation
  * @link https://php.net/manual/en/function.gmp-mod.php
- * @param resource|string|GMP $n It can be either a GMP number resource, or a
+ * @param resource|string|GMP $n <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @param resource|string|GMP $d <p>
  * The modulo that is being evaluated.
  * </p>
- * It can be either a GMP number resource, or a
+ * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return resource|GMP A GMP number resource.
  */
+#[Pure]
 function gmp_mod ($n, $d) {}
 
 /**
@@ -221,33 +234,36 @@ function gmp_mod ($n, $d) {}
  * @param resource|string|GMP $n <p>
  * The number being divided.
  * </p>
- * It can be either a GMP number resource, or a
+ * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @param resource|string|GMP $d <p>
  * The number that <i>a</i> is being divided by.
  * </p>
- * It can be either a GMP number resource, or a
+ * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return resource|GMP A GMP number resource.
  */
+#[Pure]
 function gmp_divexact ($n, $d) {}
 
 /**
  * Negate number
  * @link https://php.net/manual/en/function.gmp-neg.php
- * @param resource|string|GMP $a It can be either a GMP number resource, or a
+ * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return resource|GMP -<i>a</i>, as a GMP number.
  */
+#[Pure]
 function gmp_neg ($a) {}
 
 /**
  * Absolute value
  * @link https://php.net/manual/en/function.gmp-abs.php
- * @param resource|string|GMP $a It can be either a GMP number resource, or a
+ * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return resource|GMP the absolute value of <i>a</i>, as a GMP number.
  */
+#[Pure]
 function gmp_abs ($a) {}
 
 /**
@@ -256,19 +272,21 @@ function gmp_abs ($a) {}
  * @param resource|string|GMP $a <p>
  * The factorial number.
  * </p>
- * It can be either a GMP number resource, or a
+ * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return resource|GMP A GMP number resource.
  */
+#[Pure]
 function gmp_fact ($a) {}
 
 /**
  * Calculate square root
  * @link https://php.net/manual/en/function.gmp-sqrt.php
- * @param resource|string|GMP $a It can be either a GMP number resource, or a
+ * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return resource|GMP The integer portion of the square root, as a GMP number.
  */
+#[Pure]
 function gmp_sqrt ($a) {}
 
 /**
@@ -277,13 +295,14 @@ function gmp_sqrt ($a) {}
  * @param resource|string|GMP $a <p>
  * The number being square rooted.
  * </p>
- * It can be either a GMP number resource, or a
+ * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return array array where first element is the integer square root of
  * <i>a</i> and the second is the remainder
  * (i.e., the difference between <i>a</i> and the
  * first element squared).
  */
+#[Pure]
 function gmp_sqrtrem ($a) {}
 
 /**
@@ -292,7 +311,7 @@ function gmp_sqrtrem ($a) {}
  * @param resource|string|GMP $base <p>
  * The base number.
  * </p>
- * It can be either a GMP number resource, or a
+ * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @param int $exp <p>
  * The positive power to raise the <i>base</i>.
@@ -300,6 +319,7 @@ function gmp_sqrtrem ($a) {}
  * @return resource|GMP The new (raised) number, as a GMP number. The case of
  * 0^0 yields 1.
  */
+#[Pure]
 function gmp_pow ($base, $exp) {}
 
 /**
@@ -308,20 +328,21 @@ function gmp_pow ($base, $exp) {}
  * @param resource|string|GMP $base <p>
  * The base number.
  * </p>
- * It can be either a GMP number resource, or a
+ * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @param resource|string|GMP $exp <p>
  * The positive power to raise the <i>base</i>.
  * </p>
- * It can be either a GMP number resource, or a
+ * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @param resource|string|GMP $mod <p>
  * The modulo.
  * </p>
- * It can be either a GMP number resource, or a
+ * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return resource|GMP The new (raised) number, as a GMP number.
  */
+#[Pure]
 function gmp_powm ($base, $exp, $mod) {}
 
 /**
@@ -330,11 +351,12 @@ function gmp_powm ($base, $exp, $mod) {}
  * @param resource|string|GMP $a <p>
  * The number being checked as a perfect square.
  * </p>
- * It can be either a GMP number resource, or a
+ * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return bool <b>TRUE</b> if <i>a</i> is a perfect square,
  * <b>FALSE</b> otherwise.
  */
+#[Pure]
 function gmp_perfect_square ($a) {}
 
 /**
@@ -343,7 +365,7 @@ function gmp_perfect_square ($a) {}
  * @param resource|string|GMP $a <p>
  * The number being checked as a prime.
  * </p>
- * It can be either a GMP number resource, or a
+ * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @param int $reps [optional] <p>
  * Reasonable values
@@ -351,13 +373,14 @@ function gmp_perfect_square ($a) {}
  * 10); a higher value lowers the probability for a non-prime to
  * pass as a "probable" prime.
  * </p>
- * It can be either a GMP number resource, or a
+ * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return int If this function returns 0, <i>a</i> is
  * definitely not prime. If it returns 1, then
  * <i>a</i> is "probably" prime. If it returns 2,
  * then <i>a</i> is surely prime.
  */
+#[Pure]
 function gmp_prob_prime ($a, $reps = 10) {}
 
 /**
@@ -368,6 +391,7 @@ function gmp_prob_prime ($a, $reps = 10) {}
  * or a numeric string provided that it is possible to convert the latter to a number.</p>
  * @return GMP A random GMP number.
  */
+#[Pure]
 function gmp_random_bits($bits) {}
 
 /**
@@ -377,92 +401,100 @@ function gmp_random_bits($bits) {}
  * @param GMP $max <p>A GMP number representing the upper bound for the random number</p>
  * @return GMP A random GMP number.
  */
+#[Pure]
 function gmp_random_range(GMP $min, GMP $max) {}
 
 /**
  * Calculate GCD
  * @link https://php.net/manual/en/function.gmp-gcd.php
- * @param resource|string|GMP $a It can be either a GMP number resource, or a
+ * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param resource|string|GMP $b It can be either a GMP number resource, or a
+ * @param resource|string|GMP $b <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return resource|GMP A positive GMP number that divides into both
  * <i>a</i> and <i>b</i>.
  */
+#[Pure]
 function gmp_gcd ($a, $b) {}
 
 /**
  * Calculate GCD and multipliers
  * @link https://php.net/manual/en/function.gmp-gcdext.php
- * @param resource|string|GMP $a It can be either a GMP number resource, or a
+ * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param resource|string|GMP $b It can be either a GMP number resource, or a
+ * @param resource|string|GMP $b <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return array An array of GMP numbers.
  */
+#[Pure]
 function gmp_gcdext ($a, $b) {}
 
 /**
  * Inverse by modulo
  * @link https://php.net/manual/en/function.gmp-invert.php
- * @param resource|string|GMP $a It can be either a GMP number resource, or a
+ * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param resource|string|GMP $b It can be either a GMP number resource, or a
+ * @param resource|string|GMP $b <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return resource|GMP|false A GMP number on success or <b>FALSE</b> if an inverse does not exist.
  */
+#[Pure]
 function gmp_invert ($a, $b) {}
 
 /**
  * Jacobi symbol
  * @link https://php.net/manual/en/function.gmp-jacobi.php
- * @param resource|string|GMP $a It can be either a GMP number resource, or a
+ * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param resource|string|GMP $p It can be either a GMP number resource, or a
+ * @param resource|string|GMP $p <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * <p>
  * Should be odd and must be positive.
  * </p>
  * @return int A GMP number resource.
  */
+#[Pure]
 function gmp_jacobi ($a, $p) {}
 
 /**
  * Legendre symbol
  * @link https://php.net/manual/en/function.gmp-legendre.php
- * @param resource|string|GMP $a It can be either a GMP number resource, or a
+ * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param resource|string|GMP $p It can be either a GMP number resource, or a
+ * @param resource|string|GMP $p <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * <p>
  * Should be odd and must be positive.
  * </p>
  * @return int A GMP number resource.
  */
+#[Pure]
 function gmp_legendre ($a, $p) {}
 
 /**
  * Compare numbers
  * @link https://php.net/manual/en/function.gmp-cmp.php
- * @param resource|string|GMP $a It can be either a GMP number resource, or a
+ * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param resource|string|GMP $b It can be either a GMP number resource, or a
+ * @param resource|string|GMP $b <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return int a positive value if a &gt; b, zero if
  * a = b and a negative value if a &lt;
  * b.
  */
+#[Pure]
 function gmp_cmp ($a, $b) {}
 
 /**
  * Sign of number
  * @link https://php.net/manual/en/function.gmp-sign.php
- * @param resource|string|GMP $a It can be either a GMP number resource, or a
+ * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return int 1 if <i>a</i> is positive,
  * -1 if <i>a</i> is negative,
  * and 0 if <i>a</i> is zero.
  */
+#[Pure]
 function gmp_sign ($a) {}
 
 /**
@@ -471,54 +503,61 @@ function gmp_sign ($a) {}
  * @param int $limiter [optional] <p>
  * The limiter.
  * </p>
- * It can be either a GMP number resource, or a
+ * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return resource|GMP A random GMP number.
- * @deprecated 7.2 Use {@see gmp_random_bits()} or {@see gmp_random_range()} instead.
+ * @see gmp_random_bits()
+ * @see gmp_random_range()
  * @removed 8.0
  */
+#[Deprecated(reason: "Use see gmp_random_bits() or see gmp_random_range() instead", since: "7.2")]
+#[Pure]
 function gmp_random ($limiter = 20) {}
 
 /**
  * Bitwise AND
  * @link https://php.net/manual/en/function.gmp-and.php
- * @param resource|string|GMP $a It can be either a GMP number resource, or a
+ * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param resource|string|GMP $b It can be either a GMP number resource, or a
+ * @param resource|string|GMP $b <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return resource|GMP A GMP number representing the bitwise AND comparison.
  */
+#[Pure]
 function gmp_and ($a, $b) {}
 
 /**
  * Bitwise OR
  * @link https://php.net/manual/en/function.gmp-or.php
- * @param resource|string|GMP $a It can be either a GMP number resource, or a
+ * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param resource|string|GMP $b It can be either a GMP number resource, or a
+ * @param resource|string|GMP $b <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return resource|GMP A GMP number resource.
  */
+#[Pure]
 function gmp_or ($a, $b) {}
 
 /**
  * Calculates one's complement
  * @link https://php.net/manual/en/function.gmp-com.php
- * @param resource|string|GMP $a It can be either a GMP number resource, or a
+ * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return resource|GMP the one's complement of <i>a</i>, as a GMP number.
  */
+#[Pure]
 function gmp_com ($a) {}
 
 /**
  * Bitwise XOR
  * @link https://php.net/manual/en/function.gmp-xor.php
- * @param resource|string|GMP $a It can be either a GMP number resource, or a
+ * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param resource|string|GMP $b It can be either a GMP number resource, or a
+ * @param resource|string|GMP $b <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return resource|GMP A GMP number resource.
  */
+#[Pure]
 function gmp_xor ($a, $b) {}
 
 /**
@@ -527,7 +566,7 @@ function gmp_xor ($a, $b) {}
  * @param resource|string|GMP &$a <p>
  * The number being set to.
  * </p>
- * It can be either a GMP number resource, or a
+ * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @param int $index <p>
  * The set bit.
@@ -543,9 +582,9 @@ function gmp_setbit (&$a, $index, $set_clear = true) {}
 /**
  * Clear bit
  * @link https://php.net/manual/en/function.gmp-clrbit.php
- * @param resource|string|GMP &$a It can be either a GMP number resource, or a
+ * @param resource|string|GMP &$a <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param int $index It can be either a GMP number resource, or a
+ * @param int $index <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return void A GMP number resource.
  */
@@ -557,7 +596,7 @@ function gmp_clrbit (&$a, $index) {}
  * @param resource|string|GMP $a <p>
  * The number to scan.
  * </p>
- * It can be either a GMP number resource, or a
+ * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @param int $start <p>
  * The starting bit.
@@ -565,6 +604,7 @@ function gmp_clrbit (&$a, $index) {}
  * @return int the index of the found bit, as an integer. The
  * index starts from 0.
  */
+#[Pure]
 function gmp_scan0 ($a, $start) {}
 
 /**
@@ -573,7 +613,7 @@ function gmp_scan0 ($a, $start) {}
  * @param resource|string|GMP $a <p>
  * The number to scan.
  * </p>
- * It can be either a GMP number resource, or a
+ * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @param int $start <p>
  * The starting bit.
@@ -581,101 +621,110 @@ function gmp_scan0 ($a, $start) {}
  * @return int the index of the found bit, as an integer.
  * If no set bit is found, -1 is returned.
  */
+#[Pure]
 function gmp_scan1 ($a, $start) {}
 
 /**
  * Tests if a bit is set
  * @link https://php.net/manual/en/function.gmp-testbit.php
- * @param resource|string|GMP $a It can be either a GMP number resource, or a
+ * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @param int $index <p>
  * The bit to test
  * </p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
+#[Pure]
 function gmp_testbit ($a, $index) {}
 
 /**
  * Population count
  * @link https://php.net/manual/en/function.gmp-popcount.php
- * @param resource|string|GMP $a It can be either a GMP number resource, or a
+ * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return int The population count of <i>a</i>, as an integer.
  */
+#[Pure]
 function gmp_popcount ($a) {}
 
 /**
  * Hamming distance
  * @link https://php.net/manual/en/function.gmp-hamdist.php
- * @param resource|string|GMP $a It can be either a GMP number resource, or a
+ * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * <p>
  * It should be positive.
  * </p>
- * @param resource|string|GMP $b It can be either a GMP number resource, or a
+ * @param resource|string|GMP $b <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * <p>
  * It should be positive.
  * </p>
  * @return int A GMP number resource.
  */
+#[Pure]
 function gmp_hamdist ($a, $b) {}
 
 /**
  * Import from a binary string
  * @link https://php.net/manual/en/function.gmp-import.php
  * @param string $data The binary string being imported
- * @param integer $word_size Default value is 1. The number of bytes in each chunk of binary
+ * @param integer $word_size <p>Default value is 1. The number of bytes in each chunk of binary
  * data. This is mainly used in conjunction with the options parameter.</p>
  * @param integer $options Default value is GMP_MSW_FIRST | GMP_NATIVE_ENDIAN.
  * @return GMP|false Returns a GMP number or FALSE on failure.
  * @since 5.6.1
  */
+#[Pure]
 function gmp_import ($data, $word_size = 1, $options = GMP_MSW_FIRST | GMP_NATIVE_ENDIAN) {}
 
 /**
  * Export to a binary string
  * @link https://php.net/manual/en/function.gmp-export.php
  * @param GMP $gmpnumber The GMP number being exported
- * @param integer $word_size Default value is 1. The number of bytes in each chunk of binary
+ * @param integer $word_size <p>Default value is 1. The number of bytes in each chunk of binary
  * data. This is mainly used in conjunction with the options parameter.</p>
  * @param integer $options Default value is GMP_MSW_FIRST | GMP_NATIVE_ENDIAN.
  * @return string|false Returns a string or FALSE on failure.
  * @since 5.6.1
  */
+#[Pure]
 function gmp_export (GMP $gmpnumber, $word_size = 1, $options = GMP_MSW_FIRST | GMP_NATIVE_ENDIAN) {}
 
 /**
  * Takes the nth root of a and returns the integer component of the result.
  * @link https://php.net/manual/en/function.gmp-root.php
- * @param GMP $a Either a GMP number resource in PHP 5.5 and earlier, a GMP object in PHP 5.6
+ * @param GMP $a <p>Either a GMP number resource in PHP 5.5 and earlier, a GMP object in PHP 5.6
  * and later, or a numeric string provided that it is possible to convert the latter to a number.</p>
  * @param integer $nth The positive root to take of a.
  * @return GMP The integer component of the resultant root, as a GMP number.
  * @since 5.6
  */
+#[Pure]
 function gmp_root (GMP $a, $nth) {}
 
 /**
  * Takes the nth root of a and returns the integer component and remainder of the result.
  * @link https://php.net/manual/en/function.gmp-rootrem.php
- * @param GMP $a Either a GMP number resource in PHP 5.5 and earlier, a GMP object in PHP 5.6
+ * @param GMP $a <p>Either a GMP number resource in PHP 5.5 and earlier, a GMP object in PHP 5.6
  * and later, or a numeric string provided that it is possible to convert the latter to a number.</p>
  * @param integer $nth The positive root to take of a.
- * @return array|GMP[] A two element array, where the first element is the integer component of
+ * @return array|GMP[] <p>A two element array, where the first element is the integer component of
  * the root, and the second element is the remainder, both represented as GMP numbers.</p>
  * @since 5.6
  */
+#[Pure]
 function gmp_rootrem (GMP $a, $nth) {}
 
 /**
  * Find next prime number
  * @link https://php.net/manual/en/function.gmp-nextprime.php
- * @param resource|string|GMP $a It can be either a GMP number resource, or a
+ * @param int|resource|string|GMP $a <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return resource Return the next prime number greater than <i>a</i>,
  * as a GMP number.
  */
+#[Pure]
 function gmp_nextprime ($a) {}
 
 /**
@@ -689,6 +738,7 @@ function gmp_nextprime ($a) {}
  *
  * @since 7.3
  */
+#[Pure]
 function gmp_binomial($a, $b) {}
 
 /**
@@ -702,6 +752,7 @@ function gmp_binomial($a, $b) {}
  *
  * @since 7.3
  */
+#[Pure]
 function gmp_kronecker($a, $b) {}
 
 /**
@@ -715,6 +766,7 @@ function gmp_kronecker($a, $b) {}
  *
  * @since 7.3
  */
+#[Pure]
 function gmp_lcm($a, $b) {}
 
 /**
@@ -727,6 +779,7 @@ function gmp_lcm($a, $b) {}
  *
  * @since 7.3
  */
+#[Pure]
 function gmp_perfect_power($a) {}
 
 define ('GMP_ROUND_ZERO', 0);
