@@ -6,7 +6,7 @@
  * Objects of this class can be traversed, yielding the entries stored in the respective RAR archive.
  * Those entries can also be obtained through {@see \RarArchive::getEntry} and {@see \RarArchive::getEntries}.
  *
- * @link https://php.net/manual/ru/class.rararchive.php
+ * @link https://php.net/manual/en/class.rararchive.php
  */
 final class RarArchive implements Traversable
 {
@@ -14,10 +14,10 @@ final class RarArchive implements Traversable
      * Open RAR archive
      *
      * @param string $filename Path to the Rar archive
-     * @param string $password A plain password, if needed to decrypt the headers. It will also be used by default if
+     * @param null|string $password A plain password, if needed to decrypt the headers. It will also be used by default if
      *      encrypted files are found. Note that the files may have different passwords in respect
      *      to the headers and among them
-     * @param callable $volume_callback A function that receives one parameter – the path of the volume that was
+     * @param null|callable $volume_callback A function that receives one parameter – the path of the volume that was
      *      not found – and returns a string with the correct path for such volume or NULL if such volume does not
      *      exist or is not known. The programmer should ensure the passed function doesn't cause loops as this
      *      function is called repeatedly if the path returned in a previous call did not correspond to the needed
@@ -28,7 +28,7 @@ final class RarArchive implements Traversable
      *
      * @return RarArchive|false the requested RarArchive instance or FALSE on failure.
      */
-    public static function open($filename, $password = null, callable $volume_callback = null)
+    public static function open($filename, $password = null, ?callable $volume_callback = null)
     {
     }
     /**
@@ -107,7 +107,7 @@ final class RarArchive implements Traversable
      * archive entries will fail. Broken archives are archives for which no error is detected when the file is
      * opened but an error occurs when reading the entries.
      *
-     * @link https://php.net/manual/ru/rararchive.setallowbroken.php
+     * @link https://php.net/manual/en/rararchive.setallowbroken.php
      *
      * @param bool $allow_broken Whether to allow reading broken files (TRUE) or not (FALSE)
      *
