@@ -1,5 +1,10 @@
 <?php
 
+use JetBrains\PhpStorm\Deprecated;
+use JetBrains\PhpStorm\Internal\LanguageLevelTypeAware;
+use JetBrains\PhpStorm\Internal\PhpStormStubsElementAvailable;
+use JetBrains\PhpStorm\Pure;
+
 /**
  * Open Internet or Unix domain socket connection
  * @link https://php.net/manual/en/function.fsockopen.php
@@ -12,26 +17,26 @@
  * @param int $port [optional] <p>
  * The port number.
  * </p>
- * @param int &$errno [optional] <p>
+ * @param int &$error_code [optional] <p>
  * If provided, holds the system level error number that occurred in the
  * system-level connect() call.
  * </p>
  * <p>
  * If the value returned in errno is
  * 0 and the function returned false, it is an
- * indication that the error occurred before the 
+ * indication that the error occurred before the
  * connect() call. This is most likely due to a
  * problem initializing the socket.
  * </p>
- * @param string &$errstr [optional] <p>
+ * @param string &$error_message [optional] <p>
  * The error message as a string.
  * </p>
- * @param float $timeout [optional] <p>
+ * @param float|null $timeout [optional] <p>
  * The connection timeout, in seconds.
  * </p>
  * <p>
  * If you need to set a timeout for reading/writing data over the
- * socket, use stream_set_timeout, as the 
+ * socket, use stream_set_timeout, as the
  * timeout parameter to
  * fsockopen only applies while connecting the
  * socket.
@@ -42,7 +47,8 @@
  * fwrite, fclose, and
  * feof). If the call fails, it will return false
  */
-function fsockopen ($hostname, $port = null, &$errno = null, &$errstr = null, $timeout = null) {}
+function fsockopen (string $hostname, int $port = -1, &$error_code, &$error_message, ?float $timeout)
+{}
 
 /**
  * Open persistent Internet or Unix domain socket connection
@@ -50,12 +56,13 @@ function fsockopen ($hostname, $port = null, &$errno = null, &$errstr = null, $t
  * @see fsockopen
  * @param string $hostname
  * @param int $port [optional]
- * @param int &$errno [optional]
- * @param string &$errstr [optional]
- * @param float $timeout [optional]
+ * @param int &$error_code [optional]
+ * @param string &$error_message [optional]
+ * @param float|null $timeout [optional]
  * @return resource|false
  */
-function pfsockopen ($hostname, $port = null, &$errno = null, &$errstr = null, $timeout = null) {}
+function pfsockopen (string $hostname, int $port = -1, &$error_code, &$error_message, ?float $timeout)
+{}
 
 /**
  * Pack data into binary string
@@ -157,12 +164,14 @@ function pfsockopen ($hostname, $port = null, &$errno = null, &$errstr = null, $
  * </tr>
  * </table>
  * </p>
- * @param mixed $args [optional] <p>
+ * @param mixed ...$values [optional] <p>
  * </p>
- * @param mixed $_ [optional] 
  * @return string|false a binary string containing data or false if the format string contains errors
  */
-function pack ($format, $args = null, $_ = null) {}
+#[Pure]
+#[LanguageLevelTypeAware(["8.0" => "string"], default: "string|false")]
+function pack (string $format, ...$values)
+{}
 
 /**
  * Unpack data from binary string
@@ -170,25 +179,27 @@ function pack ($format, $args = null, $_ = null) {}
  * @param string $format <p>
  * See pack for an explanation of the format codes.
  * </p>
- * @param string $data <p>
+ * @param string $string <p>
  * The packed data.
  * </p>
  * @param int $offset [optional]
  * @return array|false an associative array containing unpacked elements of binary
  * string or false if the format string contains errors
  */
-function unpack ($format, $data, $offset = 0) {}
+#[Pure]
+function unpack (string $format, string $string, int $offset = 0): array|false
+{}
 
 /**
  * Tells what the user's browser is capable of
  * @link https://php.net/manual/en/function.get-browser.php
- * @param string $user_agent [optional] <p>
+ * @param string|null $user_agent [optional] <p>
  * The User Agent to be analyzed. By default, the value of HTTP
  * User-Agent header is used; however, you can alter this (i.e., look up
  * another browser's info) by passing this parameter.
  * </p>
  * <p>
- * You can bypass this parameter with a &null; value.
+ * You can bypass this parameter with a null value.
  * </p>
  * @param bool $return_array [optional] <p>
  * If set to true, this function will return an array
@@ -206,12 +217,14 @@ function unpack ($format, $data, $offset = 0) {}
  * cookies are accepted is to set one with setcookie,
  * reload, and check for the value.
  */
-function get_browser ($user_agent = null, $return_array = null) {}
+#[Pure]
+function get_browser (?string $user_agent, bool $return_array = false): object|array|false
+{}
 
 /**
  * One-way string encryption (hashing)
  * @link https://php.net/manual/en/function.crypt.php
- * @param string $str <p>
+ * @param string $string <p>
  * The string to be encrypted.
  * </p>
  * @param string $salt [optional] <p>
@@ -226,46 +239,73 @@ function get_browser ($user_agent = null, $return_array = null) {}
  * </p>
  * @return string|null the encrypted string or <b>NULL</b> if an error occurs
  */
-function crypt ($str, $salt = null) {}
+#[Pure]
+#[PhpStormStubsElementAvailable(to: '7.4')]
+function crypt ($string, $salt = null): ?string
+{}
+
+/**
+ * One-way string encryption (hashing)
+ * @link https://php.net/manual/en/function.crypt.php
+ * @param string $string <p>
+ * The string to be encrypted.
+ * </p>
+ * @param string $salt <p>
+ * An optional salt string to base the encryption on. If not provided,
+ * one will be randomly generated by PHP each time you call this function.
+ * PHP 5.6 or later raise E_NOTICE error if this parameter is omitted
+ * </p>
+ * <p>
+ * If you are using the supplied salt, you should be aware that the salt
+ * is generated once. If you are calling this function repeatedly, this
+ * may impact both appearance and security.
+ * </p>
+ * @return string the encrypted string or <b>NULL</b> if an error occurs
+ */
+#[Pure]
+#[PhpStormStubsElementAvailable('8.0')]
+function crypt (string $string, string $salt): string
+{}
 
 /**
  * Open directory handle
  * @link https://php.net/manual/en/function.opendir.php
- * @param string $path <p>
+ * @param string $directory <p>
  * The directory path that is to be opened
  * </p>
  * @param resource $context [optional] <p>
- * For a description of the context parameter, 
+ * For a description of the context parameter,
  * refer to the streams section of
  * the manual.
  * </p>
  * @return resource|false a directory handle resource on success, or
  * false on failure.
- * </p> 
+ * </p>
  * <p>
  * If path is not a valid directory or the
  * directory can not be opened due to permission restrictions or
  * filesystem errors, opendir returns false and
- * generates a PHP error of level 
+ * generates a PHP error of level
  * E_WARNING. You can suppress the error output of
  * opendir by prepending
  * '@' to the
  * front of the function name.
  */
-function opendir ($path, $context = null) {}
+function opendir (string $directory, $context)
+{}
 
 /**
  * Close directory handle
  * @link https://php.net/manual/en/function.closedir.php
  * @param resource $dir_handle [optional] <p>
  * The directory handle resource previously opened
- * with opendir. If the directory handle is 
- * not specified, the last link opened by opendir 
+ * with opendir. If the directory handle is
+ * not specified, the last link opened by opendir
  * is assumed.
  * </p>
- * @return void 
+ * @return void
  */
-function closedir ($dir_handle = null) {}
+function closedir ($dir_handle): void {}
 
 /**
  * Change directory
@@ -275,7 +315,8 @@ function closedir ($dir_handle = null) {}
  * </p>
  * @return bool true on success or false on failure.
  */
-function chdir ($directory) {}
+function chdir (string $directory): bool
+{}
 
 /**
  * Change the root directory
@@ -285,7 +326,8 @@ function chdir ($directory) {}
  * </p>
  * @return bool true on success or false on failure.
  */
-function chroot ($directory) {}
+function chroot (string $directory): bool
+{}
 
 /**
  * Gets the current working directory
@@ -301,33 +343,36 @@ function chroot ($directory) {}
  * modes and permissions.
  * </p>
  */
-function getcwd () {}
+#[Pure]
+function getcwd (): string|false
+{}
 
 /**
  * Rewind directory handle
  * @link https://php.net/manual/en/function.rewinddir.php
  * @param resource $dir_handle [optional] <p>
  * The directory handle resource previously opened
- * with opendir. If the directory handle is 
- * not specified, the last link opened by opendir 
+ * with opendir. If the directory handle is
+ * not specified, the last link opened by opendir
  * is assumed.
  * </p>
- * @return void 
+ * @return void
  */
-function rewinddir ($dir_handle = null) {}
+function rewinddir ($dir_handle): void {}
 
 /**
  * Read entry from directory handle
  * @link https://php.net/manual/en/function.readdir.php
  * @param resource $dir_handle [optional] <p>
  * The directory handle resource previously opened
- * with opendir. If the directory handle is 
- * not specified, the last link opened by opendir 
+ * with opendir. If the directory handle is
+ * not specified, the last link opened by opendir
  * is assumed.
  * </p>
  * @return string|false the filename on success or false on failure.
  */
-function readdir ($dir_handle = null) {}
+function readdir ($dir_handle): string|false
+{}
 
 /**
  * Return an instance of the Directory class
@@ -336,10 +381,22 @@ function readdir ($dir_handle = null) {}
  * Directory to open
  * </p>
  * @param resource $context [optional]
- * @return Directory|null|false an instance of Directory, or <b>NULL</b> with wrong
+ * @return Directory|false an instance of Directory, or <b>NULL</b> with wrong
  * parameters, or <b>FALSE</b> in case of another error
  */
-function dir ($directory, $context = null) {}
+function dir (string $directory, $context): Directory|false
+{}
+
+/**
+ * Alias of dir()
+ * @param string $directory
+ * @param resource $context
+ * @since 8.0
+ * @return Directory|false
+ * @see dir()
+ */
+function getdir(string $directory, $context = null): Directory|false
+{}
 
 /**
  * List files and directories inside the specified path
@@ -353,16 +410,17 @@ function dir ($directory, $context = null) {}
  * then the sort order is alphabetical in descending order.
  * </p>
  * @param resource $context [optional] <p>
- * For a description of the context parameter, 
+ * For a description of the context parameter,
  * refer to the streams section of
  * the manual.
  * </p>
- * @return array|false an array of filenames on success, or false on 
- * failure. If directory is not a directory, then 
- * boolean false is returned, and an error of level 
+ * @return array|false an array of filenames on success, or false on
+ * failure. If directory is not a directory, then
+ * boolean false is returned, and an error of level
  * E_WARNING is generated.
  */
-function scandir ($directory, $sorting_order = null, $context = null) {}
+function scandir (string $directory, int $sorting_order, $context): array|false
+{}
 
 /**
  * Find pathnames matching a pattern
@@ -384,9 +442,11 @@ function scandir ($directory, $sorting_order = null, $context = null) {}
  * </p>
  * <p>
  * On some systems it is impossible to distinguish between empty match and an
- * error.
+ * error.</p>
  */
-function glob ($pattern, $flags = null) {}
+#[Pure]
+function glob (string $pattern, int $flags): array|false
+{}
 
 /**
  * Gets last access time of file
@@ -397,7 +457,9 @@ function glob ($pattern, $flags = null) {}
  * @return int|false the time the file was last accessed, or false on failure.
  * The time is returned as a Unix timestamp.
  */
-function fileatime ($filename) {}
+#[Pure]
+function fileatime (string $filename): int|false
+{}
 
 /**
  * Gets inode change time of file
@@ -408,7 +470,9 @@ function fileatime ($filename) {}
  * @return int|false the time the file was last changed, or false on failure.
  * The time is returned as a Unix timestamp.
  */
-function filectime ($filename) {}
+#[Pure]
+function filectime (string $filename): int|false
+{}
 
 /**
  * Gets file group
@@ -421,7 +485,9 @@ function filectime ($filename) {}
  * posix_getgrgid to resolve it to a group name.
  * Upon failure, false is returned.
  */
-function filegroup ($filename) {}
+#[Pure]
+function filegroup (string $filename): int|false
+{}
 
 /**
  * Gets file inode
@@ -431,7 +497,9 @@ function filegroup ($filename) {}
  * </p>
  * @return int|false the inode number of the file, or false on failure.
  */
-function fileinode ($filename) {}
+#[Pure]
+function fileinode (string $filename): int|false
+{}
 
 /**
  * Gets file modification time
@@ -443,7 +511,9 @@ function fileinode ($filename) {}
  * The time is returned as a Unix timestamp, which is
  * suitable for the date function.
  */
-function filemtime ($filename) {}
+#[Pure]
+function filemtime (string $filename): int|false
+{}
 
 /**
  * Gets file owner
@@ -455,7 +525,9 @@ function filemtime ($filename) {}
  * The user ID is returned in numerical format, use
  * posix_getpwuid to resolve it to a username.
  */
-function fileowner ($filename) {}
+#[Pure]
+function fileowner (string $filename): int|false
+{}
 
 /**
  * Gets file permissions
@@ -465,7 +537,9 @@ function fileowner ($filename) {}
  * </p>
  * @return int|false the permissions on the file, or false on failure.
  */
-function fileperms ($filename) {}
+#[Pure]
+function fileperms (string $filename): int|false
+{}
 
 /**
  * Gets file size
@@ -476,7 +550,9 @@ function fileperms ($filename) {}
  * @return int|false the size of the file in bytes, or false (and generates an error
  * of level E_WARNING) in case of an error.
  */
-function filesize ($filename) {}
+#[Pure]
+function filesize (string $filename): int|false
+{}
 
 /**
  * Gets file type
@@ -492,7 +568,9 @@ function filesize ($filename) {}
  * produce an E_NOTICE message if the stat call fails
  * or if the file type is unknown.
  */
-function filetype ($filename) {}
+#[Pure]
+function filetype (string $filename): string|false
+{}
 
 /**
  * Checks whether a file or directory exists
@@ -520,7 +598,9 @@ function filetype ($filename) {}
  * <p>
  * The check is done using the real UID/GID instead of the effective one.
  */
-function file_exists ($filename) {}
+#[Pure]
+function file_exists (string $filename): bool
+{}
 
 /**
  * Tells whether the filename is writable
@@ -531,10 +611,13 @@ function file_exists ($filename) {}
  * @return bool true if the filename exists and is
  * writable.
  */
-function is_writable ($filename) {}
+#[Pure]
+function is_writable (string $filename): bool
+{}
 
 /**
- * &Alias; <function>is_writable</function>
+ * Alias:
+ * {@see is_writable}
  * @link https://php.net/manual/en/function.is-writeable.php
  * @param string $filename <p>
  * The filename being checked.
@@ -542,18 +625,22 @@ function is_writable ($filename) {}
  * @return bool true if the filename exists and is
  * writable.
  */
-function is_writeable ($filename) {}
+#[Pure]
+function is_writeable (string $filename): bool
+{}
 
 /**
- * Tells whether a file exists and is readable
+ * Tells whether a file or a directory exists and is readable
  * @link https://php.net/manual/en/function.is-readable.php
  * @param string $filename <p>
- * Path to the file.
+ * Path to the file or directory.
  * </p>
  * @return bool true if the file or directory specified by
  * filename exists and is readable, false otherwise.
  */
-function is_readable ($filename) {}
+#[Pure]
+function is_readable (string $filename): bool
+{}
 
 /**
  * Tells whether the filename is executable
@@ -564,7 +651,9 @@ function is_readable ($filename) {}
  * @return bool true if the filename exists and is executable, or false on
  * error.
  */
-function is_executable ($filename) {}
+#[Pure]
+function is_executable (string $filename): bool
+{}
 
 /**
  * Tells whether the filename is a regular file
@@ -575,7 +664,9 @@ function is_executable ($filename) {}
  * @return bool true if the filename exists and is a regular file, false
  * otherwise.
  */
-function is_file ($filename) {}
+#[Pure]
+function is_file (string $filename): bool
+{}
 
 /**
  * Tells whether the filename is a directory
@@ -583,13 +674,15 @@ function is_file ($filename) {}
  * @param string $filename <p>
  * Path to the file. If filename is a relative
  * filename, it will be checked relative to the current working
- * directory. If filename is a symbolic or hard link 
+ * directory. If filename is a symbolic or hard link
  * then the link will be resolved and checked.
  * </p>
  * @return bool true if the filename exists and is a directory, false
  * otherwise.
  */
-function is_dir ($filename) {}
+#[Pure]
+function is_dir (string $filename): bool
+{}
 
 /**
  * Tells whether the filename is a symbolic link
@@ -600,7 +693,9 @@ function is_dir ($filename) {}
  * @return bool true if the filename exists and is a symbolic link, false
  * otherwise.
  */
-function is_link ($filename) {}
+#[Pure]
+function is_link (string $filename): bool
+{}
 
 /**
  * Gives information about a file
@@ -691,7 +786,9 @@ function is_link ($filename) {}
  * <p>
  * In case of error, stat returns false.
  */
-function stat ($filename) {}
+#[Pure]
+function stat (string $filename): array|false
+{}
 
 /**
  * Gives information about a file or symbolic link
@@ -707,7 +804,9 @@ function stat ($filename) {}
  * link, the status of the symbolic link is returned, not the status of the
  * file pointed to by the symbolic link.
  */
-function lstat ($filename) {}
+#[Pure]
+function lstat (string $filename): array|false
+{}
 
 /**
  * Changes file owner
@@ -715,12 +814,13 @@ function lstat ($filename) {}
  * @param string $filename <p>
  * Path to the file.
  * </p>
- * @param mixed $user <p>
+ * @param string|int $user <p>
  * A user name or number.
  * </p>
  * @return bool true on success or false on failure.
  */
-function chown ($filename, $user) {}
+function chown (string $filename, string|int $user): bool
+{}
 
 /**
  * Changes file group
@@ -728,12 +828,13 @@ function chown ($filename, $user) {}
  * @param string $filename <p>
  * Path to the file.
  * </p>
- * @param mixed $group <p>
+ * @param string|int $group <p>
  * A group name or number.
  * </p>
  * @return bool true on success or false on failure.
  */
-function chgrp ($filename, $group) {}
+function chgrp (string $filename, string|int $group): bool
+{}
 
 /**
  * Changes user ownership of symlink
@@ -741,13 +842,14 @@ function chgrp ($filename, $group) {}
  * @param string $filename <p>
  * Path to the file.
  * </p>
- * @param mixed $user <p>
+ * @param string|int $user <p>
  * User name or number.
  * </p>
  * @return bool true on success or false on failure.
  * @since 5.1.2
  */
-function lchown ($filename, $user) {}
+function lchown (string $filename, string|int $user): bool
+{}
 
 /**
  * Changes group ownership of symlink
@@ -755,13 +857,14 @@ function lchown ($filename, $user) {}
  * @param string $filename <p>
  * Path to the symlink.
  * </p>
- * @param mixed $group <p>
+ * @param string|int $group <p>
  * The group specified by name or number.
  * </p>
  * @return bool true on success or false on failure.
  * @since 5.1.2
  */
-function lchgrp ($filename, $group) {}
+function lchgrp (string $filename, string|int $group): bool
+{}
 
 /**
  * Changes file mode
@@ -769,17 +872,17 @@ function lchgrp ($filename, $group) {}
  * @param string $filename <p>
  * Path to the file.
  * </p>
- * @param int $mode <p>
+ * @param int $permissions <p>
  * Note that mode is not automatically
  * assumed to be an octal value, so strings (such as "g+w") will
  * not work properly. To ensure the expected operation,
  * you need to prefix mode with a zero (0):
  * </p>
  * <pre>
- * <?php 
- * chmod("/somedir/somefile", 755);   // decimal; probably incorrect 
- * chmod("/somedir/somefile", "u+rwx,go+rx"); // string; incorrect 
- * chmod("/somedir/somefile", 0755);  // octal; correct value of mode 
+ * <?php
+ * chmod("/somedir/somefile", 755);   // decimal; probably incorrect
+ * chmod("/somedir/somefile", "u+rwx,go+rx"); // string; incorrect
+ * chmod("/somedir/somefile", 0755);  // octal; correct value of mode
  * ?>
  * </pre>
  * <p>
@@ -794,10 +897,10 @@ function lchgrp ($filename, $group) {}
  * about modes on Unix systems with 'man 1 chmod'
  * and 'man 2 chmod'.
  * </p>
- * <p>
  * @return bool true on success or false on failure.
  */
-function chmod ($filename, $mode) {}
+function chmod (string $filename, int $permissions): bool
+{}
 
 /**
  * Sets access and modification time of file
@@ -805,18 +908,19 @@ function chmod ($filename, $mode) {}
  * @param string $filename <p>
  * The name of the file being touched.
  * </p>
- * @param int $time [optional] <p>
- * The touch time. If time is not supplied, 
+ * @param int|null $mtime [optional] <p>
+ * The touch time. If time is not supplied,
  * the current system time is used.
  * </p>
- * @param int $atime [optional] <p>
- * If present, the access time of the given filename is set to 
+ * @param int|null $atime [optional] <p>
+ * If present, the access time of the given filename is set to
  * the value of atime. Otherwise, it is set to
  * time.
  * </p>
  * @return bool true on success or false on failure.
  */
-function touch ($filename, $time = null, $atime = null) {}
+function touch (string $filename, ?int $mtime, ?int $atime): bool
+{}
 
 /**
  * Clears file status cache
@@ -825,15 +929,15 @@ function touch ($filename, $time = null, $atime = null) {}
  * Whenever to clear realpath cache or not.
  * </p>
  * @param string $filename [optional] <p>
- * Clear realpath cache on a specific filename, only used if 
+ * Clear realpath cache on a specific filename, only used if
  * clear_realpath_cache is true.
  * </p>
- * @return void 
+ * @return void
  */
-function clearstatcache ($clear_realpath_cache = null, $filename = null) {}
+function clearstatcache (bool $clear_realpath_cache = false, string $filename): void {}
 
 /**
- * Returns the total size of a directory
+ * Returns the total size of a filesystem or disk partition
  * @link https://php.net/manual/en/function.disk-total-space.php
  * @param string $directory <p>
  * A directory of the filesystem or disk partition.
@@ -841,7 +945,8 @@ function clearstatcache ($clear_realpath_cache = null, $filename = null) {}
  * @return float|false the total number of bytes as a float
  * or false on failure.
  */
-function disk_total_space ($directory) {}
+function disk_total_space (string $directory): float|false
+{}
 
 /**
  * Returns available space in directory
@@ -857,15 +962,20 @@ function disk_total_space ($directory) {}
  * @return float|false the number of available bytes as a float
  * or false on failure.
  */
-function disk_free_space ($directory) {}
+#[Pure]
+function disk_free_space (string $directory): float|false
+{}
 
 /**
- * Alias of disk_free_space()
+ * Alias of {@see disk_free_space}
  * @link https://php.net/manual/en/function.diskfreespace.php
  * @see disk_free_space
- * @param $directory
+ * @param string $directory
+ * @return float|false
  */
-function diskfreespace ($directory) {}
+#[Pure]
+function diskfreespace (string $directory): float|false
+{}
 
 /**
  * Send mail
@@ -915,9 +1025,9 @@ function diskfreespace ($directory) {}
  * </p>
  * <p>
  * When sending mail, the mail must contain
- * a From header. This can be set with the 
+ * a From header. This can be set with the
  * additional_headers parameter, or a default
- * can be set in &php.ini;.
+ * can be set in "php.ini".
  * </p>
  * <p>
  * Failing to do this will result in an error
@@ -933,7 +1043,7 @@ function diskfreespace ($directory) {}
  * This should be a last resort, as it does not comply with
  * RFC 2822.
  * </p>
- * @param string $additional_parameters [optional] <p>
+ * @param string $additional_params [optional] <p>
  * The additional_parameters parameter
  * can be used to pass additional flags as command line options to the
  * program configured to be used when sending mail, as defined by the
@@ -948,12 +1058,13 @@ function diskfreespace ($directory) {}
  * For sendmail users, this file is /etc/mail/trusted-users.
  * </p>
  * @return bool true if the mail was successfully accepted for delivery, false otherwise.
- * </p>
  * <p>
  * It is important to note that just because the mail was accepted for delivery,
  * it does NOT mean the mail will actually reach the intended destination.
+ * </p>
  */
-function mail ($to, $subject, $message, $additional_headers = null, $additional_parameters = null) {}
+function mail (string $to, string $subject, string $message, array|string $additional_headers, string $additional_params): bool
+{}
 
 /**
  * Calculate the hash value needed by EZMLM
@@ -962,17 +1073,19 @@ function mail ($to, $subject, $message, $additional_headers = null, $additional_
  * The email address that's being hashed.
  * </p>
  * @return int The hash value of addr.
- * @deprecated 7.4
+ * @removed 8.0
  */
-function ezmlm_hash ($addr) {}
+#[Deprecated(since: '7.4')]
+function ezmlm_hash (string $addr): int
+{}
 
 /**
  * Open connection to system logger
  * @link https://php.net/manual/en/function.openlog.php
- * @param string $ident <p>
- * The string ident is added to each message. 
+ * @param string $prefix <p>
+ * The string ident is added to each message.
  * </p>
- * @param int $option <p>
+ * @param int $flags <p>
  * The option argument is used to indicate
  * what logging options will be used when generating a log message.
  * <table>
@@ -1029,7 +1142,7 @@ function ezmlm_hash ($addr) {}
  * <tr valign="top">
  * <td>LOG_AUTH</td>
  * <td>
- * security/authorization messages (use 
+ * security/authorization messages (use
  * LOG_AUTHPRIV instead
  * in systems where that constant is defined)
  * </td>
@@ -1086,6 +1199,7 @@ function ezmlm_hash ($addr) {}
  * </p>
  * @return bool true on success or false on failure.
  */
-function openlog ($ident, $option, $facility) {}
+function openlog (string $prefix, int $flags, int $facility): bool
+{}
 
 ?>
